/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.games.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.json.JsonString;

/**
 * This is a JSON template for the Application resource.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Google Play Game Services API. For a detailed
 * explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Application extends GenericJson {

  /**
   * The number of achievements visible to the currently authenticated player.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key("achievement_count")
  private Integer achievementCount;

  /**
   * The assets of the application.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<ImageAsset> assets;

  static {
    // hack to force ProGuard to consider ImageAsset used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(ImageAsset.class);
  }

  /**
   * The author of the application.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String author;

  /**
   * The category of the application.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private ApplicationCategory category;

  /**
   * The description of the application.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String description;

  /**
   * The ID of the application.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String id;

  /**
   * The instances of the application.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<Instance> instances;

  static {
    // hack to force ProGuard to consider Instance used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(Instance.class);
  }

  /**
   * Uniquely identifies the type of this resource. Value is always the fixed string
   * games#application.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * The last updated timestamp of the application.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private Long lastUpdatedTimestamp;

  /**
   * The number of leaderboards visible to the currently authenticated player.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key("leaderboard_count")
  private Integer leaderboardCount;

  /**
   * The name of the application.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String name;

  /**
   * The number of achievements visible to the currently authenticated player.
   * The value returned may be {@code null}.
   */
  public Integer getAchievementCount() {
    return achievementCount;
  }

  /**
   * The number of achievements visible to the currently authenticated player.
   * The value set may be {@code null}.
   */
  public Application setAchievementCount(Integer achievementCount) {
    this.achievementCount = achievementCount;
    return this;
  }

  /**
   * The assets of the application.
   * The value returned may be {@code null}.
   */
  public java.util.List<ImageAsset> getAssets() {
    return assets;
  }

  /**
   * The assets of the application.
   * The value set may be {@code null}.
   */
  public Application setAssets(java.util.List<ImageAsset> assets) {
    this.assets = assets;
    return this;
  }

  /**
   * The author of the application.
   * The value returned may be {@code null}.
   */
  public String getAuthor() {
    return author;
  }

  /**
   * The author of the application.
   * The value set may be {@code null}.
   */
  public Application setAuthor(String author) {
    this.author = author;
    return this;
  }

  /**
   * The category of the application.
   * The value returned may be {@code null}.
   */
  public ApplicationCategory getCategory() {
    return category;
  }

  /**
   * The category of the application.
   * The value set may be {@code null}.
   */
  public Application setCategory(ApplicationCategory category) {
    this.category = category;
    return this;
  }

  /**
   * The description of the application.
   * The value returned may be {@code null}.
   */
  public String getDescription() {
    return description;
  }

  /**
   * The description of the application.
   * The value set may be {@code null}.
   */
  public Application setDescription(String description) {
    this.description = description;
    return this;
  }

  /**
   * The ID of the application.
   * The value returned may be {@code null}.
   */
  public String getId() {
    return id;
  }

  /**
   * The ID of the application.
   * The value set may be {@code null}.
   */
  public Application setId(String id) {
    this.id = id;
    return this;
  }

  /**
   * The instances of the application.
   * The value returned may be {@code null}.
   */
  public java.util.List<Instance> getInstances() {
    return instances;
  }

  /**
   * The instances of the application.
   * The value set may be {@code null}.
   */
  public Application setInstances(java.util.List<Instance> instances) {
    this.instances = instances;
    return this;
  }

  /**
   * Uniquely identifies the type of this resource. Value is always the fixed string
   * games#application.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * Uniquely identifies the type of this resource. Value is always the fixed string
   * games#application.
   * The value set may be {@code null}.
   */
  public Application setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * The last updated timestamp of the application.
   * The value returned may be {@code null}.
   */
  public Long getLastUpdatedTimestamp() {
    return lastUpdatedTimestamp;
  }

  /**
   * The last updated timestamp of the application.
   * The value set may be {@code null}.
   */
  public Application setLastUpdatedTimestamp(Long lastUpdatedTimestamp) {
    this.lastUpdatedTimestamp = lastUpdatedTimestamp;
    return this;
  }

  /**
   * The number of leaderboards visible to the currently authenticated player.
   * The value returned may be {@code null}.
   */
  public Integer getLeaderboardCount() {
    return leaderboardCount;
  }

  /**
   * The number of leaderboards visible to the currently authenticated player.
   * The value set may be {@code null}.
   */
  public Application setLeaderboardCount(Integer leaderboardCount) {
    this.leaderboardCount = leaderboardCount;
    return this;
  }

  /**
   * The name of the application.
   * The value returned may be {@code null}.
   */
  public String getName() {
    return name;
  }

  /**
   * The name of the application.
   * The value set may be {@code null}.
   */
  public Application setName(String name) {
    this.name = name;
    return this;
  }

}
